summaryrefslogtreecommitdiffstats
path: root/src/bin/dhcp6/dhcp6_srv.cc
diff options
context:
space:
mode:
authorFrancis Dupont <fdupont@isc.org>2024-10-08 16:10:13 +0200
committerFrancis Dupont <fdupont@isc.org>2024-10-11 10:18:01 +0200
commitdc8af16a6eaf6cdcf54c63f4e050f4b052261b47 (patch)
treeabd0c72599ca0b4dae4c478ccacc3ef12c652243 /src/bin/dhcp6/dhcp6_srv.cc
parent[#3585] Completed changelog (diff)
downloadkea-dc8af16a6eaf6cdcf54c63f4e050f4b052261b47.tar.xz
kea-dc8af16a6eaf6cdcf54c63f4e050f4b052261b47.zip
[#3588] Modified no test required classes
Diffstat (limited to 'src/bin/dhcp6/dhcp6_srv.cc')
-rw-r--r--src/bin/dhcp6/dhcp6_srv.cc10
1 files changed, 7 insertions, 3 deletions
diff --git a/src/bin/dhcp6/dhcp6_srv.cc b/src/bin/dhcp6/dhcp6_srv.cc
index 6df6460603..ee4841e16e 100644
--- a/src/bin/dhcp6/dhcp6_srv.cc
+++ b/src/bin/dhcp6/dhcp6_srv.cc
@@ -4495,15 +4495,19 @@ Dhcpv6Srv::requiredClassify(const Pkt6Ptr& pkt, AllocEngine::ClientContext6& ctx
for (auto const& cclass : classes) {
const ClientClassDefPtr class_def = dict->findClass(cclass);
if (!class_def) {
- LOG_DEBUG(dhcp6_logger, DBG_DHCP6_BASIC, DHCP6_CLASS_UNDEFINED)
+ LOG_DEBUG(dhcp6_logger, DBG_DHCP6_BASIC,
+ DHCP6_REQUIRED_CLASS_UNDEFINED)
.arg(cclass);
+ // Ignore it as it can't have an attached action
continue;
}
const ExpressionPtr& expr_ptr = class_def->getMatchExpr();
// Nothing to do without an expression to evaluate
if (!expr_ptr) {
- LOG_DEBUG(dhcp6_logger, DBG_DHCP6_BASIC, DHCP6_CLASS_UNTESTABLE)
+ LOG_DEBUG(dhcp6_logger, DBG_DHCP6_BASIC,
+ DHCP6_REQUIRED_CLASS_UNTESTABLE)
.arg(cclass);
+ pkt->addClass(cclass);
continue;
}
// Evaluate the expression which can return false (no match),
@@ -4495,15 +4495,19 @@ Dhcpv6Srv::requiredClassify(const Pkt6Ptr& pkt, AllocEngine::ClientContext6& ctx
}
const ExpressionPtr& expr_ptr = class_def->getMatchExpr();
- // Nothing to do without an expression to evaluate
+ // Add a class without an expression to evaluate
if (!expr_ptr) {